@@ -76,9 +76,7 @@ class ConfigureDevice(QtWidgets.QDialog):
                     if len(options['parent'].children):
                         for key, value in options['parent'].child(0).info.items():
                             if key == 'device':
-                                host = self.tango_host.split(':')
-                                self._class = [PyTango.Database(host[0], host[1]).get_device_info(value).class_name]
-                                # self._class = [hu.getClassNameByDevice(value, self.tango_host)]
+                                self._class = [hu.getClassNameByDevice(value, self.tango_host)]
 
                 self._ui.fr_personal_properties.setVisible(True)
 
